@@ -8,8 +8,11 @@ and the [website](index.html)
 renders these as side-by-side formatted notes.
 We believe these would help you understand these algorithms better.
 
+![Screenshot](https://nn.labml.ai/dqn-light.png)
+
 We are actively maintaining this repo and adding new
 implementations.
+[![Twitter](https://img.shields.io/twitter/follow/labmlai?style=social)](https://twitter.com/labmlai) for updates.
 
 ## Modules
 
@@ -42,6 +45,8 @@ implementations.
 
 #### ✨ [ResNet](resnet/index.html)
 
+#### ✨ [ConvMixer](conv_mixer/index.html)
+
 #### ✨ [Capsule Networks](capsule_networks/index.html)
 
 #### ✨ [Generative Adversarial Networks](gan/index.html)
@@ -52,6 +57,10 @@ implementations.
 * [Wasserstein GAN with Gradient Penalty](gan/wasserstein/gradient_penalty/index.html)
 * [StyleGAN 2](gan/stylegan/index.html)
 
+#### ✨ [Diffusion models](diffusion/index.html)
+
+* [Denoising Diffusion Probabilistic Models (DDPM)](diffusion/ddpm/index.html)
+
 #### ✨ [Sketch RNN](sketch_rnn/index.html)
 
 #### ✨ Graph Neural Networks
